stalker.core.models.FilenameTemplate
====================================

.. inheritance-diagram::
     stalker.core.models.FilenameTemplate
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: FilenameTemplate
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FilenameTemplate.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FilenameTemplate.code
      ~FilenameTemplate.created_by
      ~FilenameTemplate.date_created
      ~FilenameTemplate.date_updated
      ~FilenameTemplate.description
      ~FilenameTemplate.file_code
      ~FilenameTemplate.name
      ~FilenameTemplate.nice_name
      ~FilenameTemplate.notes
      ~FilenameTemplate.output_file_code
      ~FilenameTemplate.output_is_relative
      ~FilenameTemplate.output_path_code
      ~FilenameTemplate.path_code
      ~FilenameTemplate.tags
      ~FilenameTemplate.target_entity_type
      ~FilenameTemplate.type
      ~FilenameTemplate.updated_by
   
   